@@ -25,13 +25,15 @@ sub gen_NPCmessages
 
 ### use a message parser for seeking a sample of return messages
 sub interpolate_character {
-	my ($self, $fieldedmsg, $nameofentity) = @_;
+	my ($self, $fieldedmsg, $nameofentity, $surroundings) = @_;
 
 	if ($nameofentity =~ m/(G|g)nome/) { ### FIXME match nome of gnome
 		my $msgparser = RogueCurses::Messages::gnomemessageparser;
 	
-		### draw sample from parsed messages
-		my @samples = ($msgparser->parse_speed_partial_grep($fieldedmsg), );
+		### draw sample from parsed messages, @samples are probabilities
+		my @samples = (
+			$msgparser->parse_speed_partial_grep($fieldedmsg, $surroundings), 
+		);
 	}
 
 }
